@@ -57,7 +57,10 @@ class InSPyReNet(nn.Module):
         super(InSPyReNet, self).to(device)
         return self
     
-    def cuda(self, idx=0):
+    def cuda(self, idx=None):
+        if idx is None:
+            idx = torch.cuda.current_device()
+            
         self.to(device="cuda:{}".format(idx))
         return self
 
