@@ -185,4 +185,4 @@ def console():
                 vcam.send(out)
                 vcam.sleep_until_next_frame()
             else:
-                cv2.imshow('transparent-background', out)
\ No newline at end of file
+                cv2.imshow('transparent-background', cv2.cvtColor(out, cv2.COLOR_BGR2RGB))
\ No newline at end of file
